@@ -43,20 +43,24 @@ class calibration_module:
         db_agent=None,
         verbosity=True,
     ):
-
         self.moduleID = moduleID
         self.calibration = calibration
         self.db_agent = db_agent
+        if self.db_agent is None:
+            self.db_agent = calibration_DB_agent()
         self.verbosity = verbosity
         self.status = False
+
+        self.row_calib = None
+        self.mac_address = modID2mac(self.moduleID)
+        self.get_compass_info()
+
         if calibration is not None:
             self.status = True
 
         self.df = reader.df
         self.df = self.df[self.df["DOMID"] == self.moduleID].copy()
 
-        self.mac_address = modID2mac(self.moduleID)
-
         if self.verbosity:
             print("DOM mac address : {}".format(self.mac_address))
 
@@ -121,6 +125,33 @@ class calibration_module:
 
         return pd.concat((df, calib), axis=1)
 
+    def get_compass_info(self):
+        # Get CLB UPI
+        self.CLB_UPI = self.db_agent.get_CLB_UPI(self.mac_address)
+
+        # Get Compass UPI
+        self.compass_UPI = None
+        self.compassSN = 0
+        self.compassVariant = "UNKNOWN"
+
+        try:
+            self.compass_UPI = self.db_agent.get_compass_UPI(self.CLB_UPI)
+        except:
+            print("Impossible to find compass:")
+            print(f"\tDOM mac address = {self.mac_address}")
+            print(f"\tCLB UPI = {self.CLB_UPI}")
+            self.row_calib = pd.Series(
+                {
+                    "TESTNAME": "Unknown compass",
+                    "DOMID": self.moduleID,
+                    "FIRMWARE_VERSION": "-",
+                }
+            )
+            return
+        # Extract compass serial number
+        self.compassSN = int(self.compass_UPI.split(".")[-1])
+        self.compassVariant = self.compass_UPI.split("/")[1]
+
 
 class calib_DB(calibration_module):
     """
@@ -141,7 +172,6 @@ class calib_DB(calibration_module):
     """
 
     def __init__(self, reader, moduleID, calibrate=True, db_agent=None, verbosity=True):
-
         # Calling parent init without calibration prepare everything
         # but doesn't apply calibration, ignoring calibrate argument
         super().__init__(reader, moduleID, None, calibrate, db_agent, verbosity)
@@ -167,38 +197,6 @@ class calib_DB(calibration_module):
         #. Get calibration from ahrscalib streamDS
         """
 
-        # Initialize calibration row
-        self.row_calib = None
-        self.compassVariant = ""
-
-        # Check for external DB agent
-        if self.db_agent is None:
-            self.db_agent = calibration_DB_agent()
-
-        # Get CLB UPI
-        self.CLB_UPI = self.db_agent.get_CLB_UPI(self.mac_address)
-
-        # Get Compass UPI
-        self.compass_UPI = None
-
-        try:
-            self.compass_UPI = self.db_agent.get_compass_UPI(self.CLB_UPI)
-        except:
-            print("Impossible to find compass:")
-            print(f"\tDOM mac address = {self.mac_address}")
-            print(f"\tCLB UPI = {self.CLB_UPI}")
-            self.row_calib = pd.Series(
-                {
-                    "TESTNAME": "Unknown compass",
-                    "DOMID": self.moduleID,
-                    "FIRMWARE_VERSION": "-",
-                }
-            )
-            return
-        # Extract compass serial number
-        self.compassSN = int(self.compass_UPI.split(".")[-1])
-        self.compassVariant = self.compass_UPI.split("/")[1]
-
         # Check if floor ID == 0
         # If yes, it's a base module : no calibration
         if "FLOORID" in self.df.columns:
@@ -359,6 +357,48 @@ class calib_self_sphere:
         plt.tight_layout()
 
 
+class zero_calibration(calibration_module):
+    """
+    Module to apply empty calibration
+
+    Parameters:
+    -----------
+    reader: km3compass reader object
+      Reader object, either CSK or -something else-
+    moduleID: int
+      DOM module ID inside the file.
+    calibrate: bool, default = True
+      Apply or not the calibration. Can be turned off to modify calibration.
+    db_agent: calibration_DB_agent object
+      Provide external calibration_DB_agent object, avoiding additional query to DB
+    verbosity: bool
+      Toggle verbosity during the calibration process
+    """
+
+    def __init__(self, reader, moduleID, calibrate=True, db_agent=None, verbosity=True):
+        super().__init__(reader, moduleID, None, calibrate, db_agent, verbosity)
+        self.calibration = calibration_object(
+            compass_SN=self.compassSN,
+            compass_UPI=self.compass_UPI,
+            type="Empty_calibration",
+            source=f"km3compass-{version}",
+        )
+
+        self.status = True
+        self.row_calib = pd.Series(
+            {
+                "TESTNAME": "empty_calibration",
+                "DOMID": self.moduleID,
+                "FIRMWARE_VERSION": "-",
+            }
+        )
+        print(self.get_summary_df())
+        print(self.calibration)
+
+        if calibrate and self.status:
+            self.apply_calibration()
+
+
 class detector_calibration:
     """
     Module to calibrate a sea dataset
@@ -399,8 +439,7 @@ class detector_calibration:
 
         # Loop over modules
         for modID in np.unique(self.reader.df["DOMID"]):
-
-            calib = calib_DB(
+            calib = self.calib_module(
                 self.reader,
                 int(modID),
                 db_agent=self.db_agent,
@@ -839,6 +878,7 @@ class calib_from_expected_field:
 
         # Reduce the df to one line per DOM, that contains the mean value of the field
         df = df.groupby("DOMID").mean().reset_index()
+
         # Use the CLBUPI, added when calibrating, to add the compassUPI
         def fail_proof_compass_UPI(domID):
             try:
@@ -849,6 +889,7 @@ class calib_from_expected_field:
 
         df["Compass_UPI"] = df["DOMID"].apply(fail_proof_compass_UPI)
         df = df.dropna(subset=["Compass_UPI"])
+
         # Declare and use a function to convert compass_UPI to
         def CompassUPI_to_variant(upi):
             return upi.split("/")[1]
